==> haskell-hslua-0.9.5.2-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 0.9.5.2
id: hslua-0.9.5.2-4ZQd8AwvtS5GRdzlC1yXla
key: hslua-0.9.5.2-4ZQd8AwvtS5GRdzlC1yXla
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
stability: beta
synopsis: A Lua language interpreter embedding in Haskell
description:
    The Foreign.Lua module is a wrapper of Lua language
    interpreter as described on
    <https://www.lua.org/ lua.org>.
    .
    This package contains a full Lua interpreter version
    5.3.4. If you want to link it with a system-wide Lua
    installation, use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: f09767b1a675e4b511f34beeb38124ae
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Api Foreign.Lua.Api.Constants
    Foreign.Lua.Api.RawBindings Foreign.Lua.Api.Types
    Foreign.Lua.FunctionCalling Foreign.Lua.Types
    Foreign.Lua.Types.Error Foreign.Lua.Types.FromLuaStack
    Foreign.Lua.Types.Lua Foreign.Lua.Types.ToLuaStack Foreign.Lua.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-0.9.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-0.9.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hslua-0.9.5.2
hs-libraries: HShslua-0.9.5.2-4ZQd8AwvtS5GRdzlC1yXla
extra-libraries:
    lua m
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf mtl-2.2.2 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-0.9.5.2-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 0.9.5.2
id: hslua-0.9.5.2-4dAgTRZjqyhHgKHXLvHQBj
key: hslua-0.9.5.2-4dAgTRZjqyhHgKHXLvHQBj
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
stability: beta
synopsis: A Lua language interpreter embedding in Haskell
description:
    The Foreign.Lua module is a wrapper of Lua language
    interpreter as described on
    <https://www.lua.org/ lua.org>.
    .
    This package contains a full Lua interpreter version
    5.3.4. If you want to link it with a system-wide Lua
    installation, use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: 0276d871aea29454047bb4277f911fe1
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Api Foreign.Lua.Api.Constants
    Foreign.Lua.Api.RawBindings Foreign.Lua.Api.Types
    Foreign.Lua.FunctionCalling Foreign.Lua.Types
    Foreign.Lua.Types.Error Foreign.Lua.Types.FromLuaStack
    Foreign.Lua.Types.Lua Foreign.Lua.Types.ToLuaStack Foreign.Lua.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-0.9.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-0.9.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hslua-0.9.5.2
hs-libraries: HShslua-0.9.5.2-4dAgTRZjqyhHgKHXLvHQBj
extra-libraries:
    lua m
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf mtl-2.2.2 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
